Crate schema_guard_tokio

Crate schema_guard_tokio 

Modules

column
grant
index
loader
schema
table
utils

Structs

MigrationOptions
Migration option for column types, indexes, triggers and grant/revoke access. By default, all false - return exception on potentially destructive changes.

Functions

get_schema
load_schema_from_file
load_schema_from_src
migrate
main entry point to apply schema from yaml to the database return statements to execute
migrate1
Migrate one yaml schema file with options
migrate_opt
simplified migrate of one yaml file with options
parse_yaml_schema
filename is for logging reference only