Modules
Structs
- Migration
Options - Migration option for column types, indexes, triggers and grant/revoke access. By default, all false - return exception on potentially destructive changes.
Functions
- get_
schema - load_
schema_ from_ file - load_
schema_ from_ src - migrate
- main entry point to apply schema from yaml to the database return statements to execute
- migrate1
- Migrate one yaml schema file with options
- migrate_
opt - simplified migrate of one yaml file with options
- parse_
yaml_ schema - filename is for logging reference only